using System;
using Forms.Module.Contracts;
using Forms.Module.Common.Model;
using System.Collections.Generic;
using System.Linq;
using Forms.Module.Contracts.Services.Logger;

namespace Forms.Modules.TEST_MODULE.Antecedents
{
    public class Model_ATCD : global::Forms.Modules.TEST_MODULE.Antecedents.ModelBase_ATCD
    {
        public Model_ATCD(global::Forms.Module.Common.EditionContext context)
            : base(context)
        {
        }

        protected override void OuvrirATCDDistant(IExecutionContext context, string param_folder, string param_inclusion_cible)
        {
            this.folder.Value = param_folder;
            this.actd_import.Value = null;
            MultipleInsertModelFieldEditor<Inclusions.Model_incl_antecedents> incl_cible = null;

            incl_cible = this.antecedents;

            if (incl_cible != null && incl_cible.Items.Count > 0)
            {
                List<ExportATCD> listeImport = new List<ExportATCD>();
                ExportATCD importAntecedent = new ExportATCD() { type = "antecedent" };
                ExportATCD importAllergies = new ExportATCD() { type = "allergie" };
                ExportATCD importPsychiatrie = new ExportATCD() { type = "psychologie" };


                foreach (var atcd in incl_cible.Items)
                {
                    if (atcd.type_antecedent.Value != "ALL" && atcd.type_antecedent.Value != "PSY")
                    {
                        importAntecedent.list.Add(atcd.id.Value.Value);
                    }
                    else if (atcd.type_antecedent.Value == "PSY")
                    {
                        importPsychiatrie.list.Add(atcd.id.Value.Value);
                    }
                    else if (atcd.type_antecedent.Value == "ALL")
                    {
                        importAllergies.list.Add(atcd.id.Value.Value);
                    }
                }


                if (importAntecedent.list.Any())
                {
                    listeImport.Add(importAntecedent);
                }

                if (importAllergies.list.Any())
                {
                    listeImport.Add(importAllergies);
                }

                if (importPsychiatrie.list.Any())
                {
                    listeImport.Add(importPsychiatrie);
                }

                this.actd_import.Value = new System.Web.Script.Serialization.JavaScriptSerializer().Serialize(listeImport);
            }
        }

        private string ObtenirTypeAntecedent(int antecedentId)
        {
            string typeAntecedent = string.Empty;

            switch (antecedentId)
            {
                case 1:
                    typeAntecedent = "MED";
                    break;
                case 2:
                    typeAntecedent = "CHIR";
                    break;
                case 3:
                    typeAntecedent = "GYN";
                    break;
                case 4:
                    typeAntecedent = "FAM";
                    break;
                case 5:
                    typeAntecedent = "ALL";
                    break;
            }

            return typeAntecedent;

        }

        protected override void ExportATCD(IExecutionContext context, string PARAMETERS)
        {
            this.antecedents.Items.Clear();

            this.erreur_recup_antecedent.Value = string.Empty;
            //enum typeAntecendet {
            //1 med
            //2 chir
            //3 gyn
            //4 fam
            //5 all
            //}

            try
            {
                List<ExportATCD> listExportATCD = new System.Web.Script.Serialization.JavaScriptSerializer().Deserialize<List<ExportATCD>>(PARAMETERS);

                if (listExportATCD.Count > 0)
                {
                    #region Traitements des antcdents exports
                    ExportATCD exportAntecedent = listExportATCD.Where(e => e.type == "antecedent").FirstOrDefault();
                    if (exportAntecedent != null)
                    {
                        var antecedentsListe = ModuleAPI.VSMService.GetAntecedentByIds(exportAntecedent.list, EditionContext.ContextData.UserId);

                        if (antecedentsListe.Count >= 1)
                        {
                            foreach (var atcd in antecedentsListe.OrderBy(a => a.TypeAntecedentId))
                            {
                                var item = new Inclusions.Model_incl_antecedents(EditionContext);
                                item.id.Value = atcd.Id;
                                item.date_antecedent.Value = atcd.DateSaisieForEditing;
                                item.libelle_antecedent.Value = atcd.Code + " " + atcd.Libelle;
                                item.type_antecedent.Value = ObtenirTypeAntecedent(atcd.TypeAntecedentId);
                                item.commentaire_antecedent.Value = atcd.Commentaire;

                                this.antecedents.Items.Add(item);
                            }
                        }
                    }
                    #endregion

                    #region Traitements des allergies exportes
                    ExportATCD exportAllergies = listExportATCD.Where(e => e.type == "allergie").FirstOrDefault();
                    if (exportAllergies != null)
                    {
                        var listeAllergies = ModuleAPI.VSMService.GetAllergieByIds(exportAllergies.list, EditionContext.ContextData.UserId);

                        if (listeAllergies.Count >= 1)
                        {
                            foreach (var allergie in listeAllergies.OrderBy(a => a.TypeAntecedentId))
                            {
                                var item = new Inclusions.Model_incl_antecedents(EditionContext);
                                item.id.Value = allergie.Id;
                                item.date_antecedent.Value = allergie.DateSaisie.ToShortDateString();
                                item.libelle_antecedent.Value = allergie.Code + " " + allergie.Libelle;
                                item.commentaire_antecedent.Value = allergie.Manifestation;
                                item.type_antecedent.Value = "ALL";

                                this.antecedents.Items.Add(item);
                            }
                        }
                    }
                    #endregion

                    #region Traitements des antcdents psychiatriques exports
                    ExportATCD exportPsy = listExportATCD.Where(e => e.type == "psychiatrie").FirstOrDefault();
                    if (exportPsy != null)
                    {
                        var listePsy = ModuleAPI.VSMService.RecupererTroublePsyParIds(exportAllergies.list);

                        if (listePsy.Count >= 1)
                        {
                            foreach (var antecedentPsy in listePsy)
                            {
                                var item = new Inclusions.Model_incl_antecedents(EditionContext);
                                item.id.Value = antecedentPsy.Id;
                                item.date_antecedent.Value = antecedentPsy.DateSaisie.HasValue && antecedentPsy.DateSaisie.Value != DateTime.MinValue ? antecedentPsy.DateSaisie.Value.ToString("d") : null;
                                item.libelle_antecedent.Value = antecedentPsy.CodeCim + " " + antecedentPsy.Libelle;
                                item.commentaire_antecedent.Value = antecedentPsy.Commentaire;
                                item.type_antecedent.Value = "PSY";

                                this.antecedents.Items.Add(item);
                            }
                        }
                    }
                    #endregion
                }
            }
            catch (Exception ex)
            {
                if (string.IsNullOrEmpty(this.erreur_recup_antecedent.Value))
                {
                    this.erreur_recup_antecedent.Value = "Une erreur est survenue lors de la rcupration des antcdents depuis le module Antcdent mdicale";
                    ModuleAPI.LoggerService.Error(new LogOptions()
                    {
                        Message = "Une erreur est survenue lors de la rcupration des antcdents depuis le module Antcdent mdicale",
                        Exception = ex
                    });
                }
            }
        }

    }

}

